@@ -7,7 +7,7 @@ from pydantic import BaseModel, ValidationError
 from pydantic.dataclasses import dataclass as pydantic_dataclass, \
     is_builtin_dataclass
 from pydantic.schema import model_schema
-from flask import Response, jsonify, request, g
+from flask import Response, jsonify, request, g, current_app
 from werkzeug.datastructures import Headers
 from werkzeug.exceptions import BadRequest
 
@@ -31,9 +31,6 @@ class DataSource(Enum):
 def check_query_string_schema(query_string: PydanticModel) -> PydanticModel:
     if is_builtin_dataclass(query_string):
         query_string = pydantic_dataclass(query_string).__pydantic_model__
-    query_string_schema = model_schema(query_string)
-    if len(query_string_schema.get("required", [])) != 0:
-        raise SchemaInvalidError("Fields must be optional")
     return query_string
 
 
@@ -242,7 +239,7 @@ def validate(
             if err:
                 return jsonify(validation_error=err), BadRequest.code
 
-            result = func(*args, **kwargs)
+            result = current_app.ensure_async(func)(*args, **kwargs)
 
             if responses:
                 return check_response(result, responses)
